@@ -3,6 +3,7 @@ import yaml
 import sys
 import os
 from tron.devtron_api import DevtronApplication
+from tron.utils import CustomDumper, dump_yaml
 
 
 def validate_devtron_credentials(devtron_url, api_token):
@@ -80,7 +81,7 @@ def main(ctx, config, devtron_url, api_token, version):
             click.echo(f"tron version {__version__}")
         except:
             # Fallback to hardcoded version if import fails
-            click.echo("tron version 0.2.0")
+            click.echo("tron version 0.2.2")
         ctx.exit()
     
     ctx.ensure_object(dict)
@@ -169,18 +170,6 @@ def update_app(ctx, config, devtron_url, api_token, allow_deletion):
         sys.exit(1)
 
 
-# Custom YAML Dumper for multi-line strings
-class CustomDumper(yaml.SafeDumper):
-    pass
-
-def literal_presenter(dumper, data):
-    if '\n' in data and data.strip():
-        return dumper.represent_scalar('tag:yaml.org,2002:str', data, style='|')
-    return dumper.represent_scalar('tag:yaml.org,2002:str', data)
-
-CustomDumper.add_representer(str, literal_presenter)
-
-
 @main.command()
 @global_options
 @click.option('--app', required=True, help='Name of the application to fetch')
@@ -195,9 +184,9 @@ def get_app(ctx, config, devtron_url, api_token, app, output):
     result = devtron_api.get_application(app)
     if result['success']:
         config_data = result['config_data']
-        click.echo()  # Empty line
+        
         # Output in YAML format with proper multi-line string handling
-        yaml_output = yaml.dump(config_data, Dumper=CustomDumper, default_flow_style=False, allow_unicode=True, sort_keys=False)
+        yaml_output = dump_yaml(config_data)
         
         if output:
             # Save to file
