@@ -1,3 +1,4 @@
+from tron.core.app.env_override_configurations.overrideDeploymentTemplate import EnvOverrideHandler
 from tron.core.app.workflow.cd_pipeline.cd_pipeline_models import *
 from tron.core.app.workflow.ci_pipeline.ci_pipeline_handler import *
 from tron.utils import DevtronUtils
@@ -125,6 +126,14 @@ class CdPipelineHandlers:
                     "error": "Failed to get the ns details"
                 }
             namespace = get_ns.get("namespace")
+            environment_name = cd_config.get("environment_name", "")
+            get_env_id = DevtronUtils.get_env_id(base_url, headers, environment_name)
+            if not get_env_id["success"]:
+                return {
+                    "success": False,
+                    "error": "Failed to get env_id"
+                }
+            env_id = get_env_id.get("environment_id")
 
             cd_pipeline = CdPipelineHandlers.get_cd_pipeline(base_url, headers, app_id, cd_pipeline_id)
             if not cd_pipeline["success"]:
@@ -154,13 +163,19 @@ class CdPipelineHandlers:
 
             if plugins:
                 for plugin in plugins:
-                    plugin_details_result = DevtronUtils.get_plugin_details_by_name(base_url, headers, plugin.get("name", ""))
-                    if not plugin_details_result["success"]:
-                        return {
-                            "success": False,
-                            "error": "Plugin not found"
-                        }
-                    applied_plugin_metadata.append(plugin_details_result.get("plugin", ""))
+                    # Only process plugin types, skip custom types
+                    plugin_type = plugin.get("type", "plugin").lower()
+                    if plugin_type == "plugin":
+                        plugin_name = plugin.get("name", "")
+                        if not plugin_name:
+                            continue
+                        plugin_details_result = DevtronUtils.get_plugin_details_by_name(base_url, headers, plugin_name)
+                        if not plugin_details_result["success"]:
+                            return {
+                                "success": False,
+                                "error": f"Plugin '{plugin_name}' not found"
+                            }
+                        applied_plugin_metadata.append(plugin_details_result.get("plugin", ""))
 
             pipeline_plugin_ids = CdPipelineHandlers.get_pre_post_deploy_plugin_ids(cd)
             plugin_metadata = {}
@@ -206,6 +221,14 @@ class CdPipelineHandlers:
                     "error": patch_cd_result["error"]
                 }
             print("CD Pipeline updated successfully")
+
+            handle_env_override_result = EnvOverrideHandler.handle_env_override(base_url, headers, app_id, cd_config, environment_name, env_id, namespace)
+            if not handle_env_override_result["success"]:
+                print("Env override patch failed")
+                return {
+                    "success": False,
+                    "error": handle_env_override_result["error"]
+                }
             return {
                 "success": True,
                 "message": "CD Pipeline updated"
@@ -382,9 +405,13 @@ class CdPipelineHandlers:
         plugin_ids = []
         if cd_pipeline.pre_deploy_stage:
             for step in cd_pipeline.pre_deploy_stage.steps:
-                plugin_ids.append(step.plugin_ref_step_detail.plugin_id)
+                # Only collect plugin IDs for REF_PLUGIN steps, skip INLINE/custom steps
+                if step.step_type == "REF_PLUGIN" and step.plugin_ref_step_detail:
+                    plugin_ids.append(step.plugin_ref_step_detail.plugin_id)
         if cd_pipeline.post_deploy_stage:
             for step in cd_pipeline.post_deploy_stage.steps:
-                plugin_ids.append(step.plugin_ref_step_detail.plugin_id)
+                # Only collect plugin IDs for REF_PLUGIN steps, skip INLINE/custom steps
+                if step.step_type == "REF_PLUGIN" and step.plugin_ref_step_detail:
+                    plugin_ids.append(step.plugin_ref_step_detail.plugin_id)
 
         return plugin_ids
